@@ -96,7 +96,7 @@ class RawFSItem:
         count = 0
 
         libcalamares.utils.debug("Copying {} to {}".format(self.source, self.destination))
-        if libcalamares.job.configuration["bogus"]:
+        if libcalamares.job.configuration.get("bogus", False):
             return
 
         srcsize, srcblksize = get_device_size(self.source)
