@@ -32,16 +32,14 @@ CALAMARES_PLUGIN_FACTORY_DEFINITION( WelcomeViewStepFactory, registerPlugin< Wel
 
 WelcomeViewStep::WelcomeViewStep( QObject* parent )
     : Calamares::ViewStep( parent )
-    , m_requirementsChecker( new GeneralRequirements( this ) )
     , m_conf( new Config( this ) )
+    , m_widget( new WelcomePage( m_conf ) )
+    , m_requirementsChecker( new GeneralRequirements( this ) )
 {
     connect( Calamares::ModuleManager::instance(),
              &Calamares::ModuleManager::requirementsComplete,
              this,
              &WelcomeViewStep::nextStatusChanged );
-
-    // the instance of the qqc2 or qwidgets page
-    m_widget = new WelcomePage( m_conf );
     connect( m_conf, &Config::localeIndexChanged, m_widget, &WelcomePage::externallySelectedLanguage );
 }
 
